#!/bin/bash
#shell script for handling DSCOVR real-time data and GFZ Potsdam Kp/ap quicklook data
#duration: ~XX seconds
date --utc -d 'today' '+%Y-%m-%d %H:%M:%S dscovr_rtsw_plot.sh'
thisFile=$(readlink -f $BASH_SOURCE)
thisFilePath=$(dirname $(readlink -f $BASH_SOURCE))

#test if folder exists, if not create it:
data="data/"
if [ ! -d $data ]; then mkdir -p $data; fi

#download latest files
#swpcDscovrFile="http://services.swpc.noaa.gov/experimental/text/dscovr-solar-wind-arrival.txt"
swpcUrl="http://services.swpc.noaa.gov/products/solar-wind/"
swpcDscovrMagJson="mag-7-day.json"
swpcDscovrPlasmaJson="plasma-7-day.json"
#wget $swpcDscovrFile -q -N
wget $swpcUrl$swpcDscovrMagJson -q -N -P $data
wget $swpcUrl$swpcDscovrPlasmaJson -q -N -P $data
rm $data"index.html" -f

cd $data
#convert files *.json to *.txt
swpcDscovrMagTxt="mag-7-day.txt"
swpcDscovrPlasmaTxt="plasma-7-day.txt"
#introduce newlines
sed 's/\],\[/\n/g' $swpcDscovrMagJson > $swpcDscovrMagTxt
#separate with tabs
sed -i 's/,/\t/g' $swpcDscovrMagTxt
sed -i 's/ /\t/g' $swpcDscovrMagTxt
#remove " and .000
sed -i 's/"//g' $swpcDscovrMagTxt
sed -i 's/:00.000/:00/g' $swpcDscovrMagTxt
#remove brackets
sed -i 's/\[\[/#/g' $swpcDscovrMagTxt
sed -i 's/\]\]//g' $swpcDscovrMagTxt

#introduce newlines
sed 's/\],\[/\n/g' $swpcDscovrPlasmaJson > $swpcDscovrPlasmaTxt
#separate with tabs
sed -i 's/,/\t/g' $swpcDscovrPlasmaTxt
sed -i 's/ /\t/g' $swpcDscovrPlasmaTxt
#remove " and .000
sed -i 's/"//g' $swpcDscovrPlasmaTxt
sed -i 's/:00.000/:00/g' $swpcDscovrPlasmaTxt
#remove brackets
sed -i 's/\[\[/#/g' $swpcDscovrPlasmaTxt
sed -i 's/\]\]//g' $swpcDscovrPlasmaTxt
cd ..

#run gnuplot: 
#gnuplot dscovr_rtsw_gps.txt

cd $data
#build 4-day velocity file for Frederik's display (5-min cadence):
tmp="dscovr_dsplay_temp.txt"
paste $swpcDscovrMagTxt $swpcDscovrPlasmaTxt > $tmp
tmp2="dscovr_dsplay2_temp.txt"
tail -5760 $tmp > $tmp2
day4ago="`date --utc -d '4 days ago' '+%Y-%m-%d'`"
awk -v day4ago="${day4ago}" 'BEGIN{FIELDWIDTHS="10 150"} {if($1!=day4ago) {print $0}}' $tmp2 > $tmp
awk 'NR%5==0' $tmp > $tmp2
sed -i 's/-\([0-9][0-9]\)-/ \1 /g' $tmp2
sed -i 's/:00\t/\t/g' $tmp2
sed -i 's/://g' $tmp2
head -n -1 $tmp2 > $tmp
dscovrDsplayTxt="dscovr_dsplay_4day_5min.txt"
awk 'BEGIN{} {printf "%g %02g %02g  %04g   00000       0    0% 8.1f% 8.1f% 8.1f% 8.1f% 8.1f% 8.1f\t%g %02g %02g  %04g   00000       0    0   % 8.1f   % 8.1f   % 10.2e\n",$1,$2,$3,$4,$5,$6,$7,$10,$9,$8,$11,$12,$13,$14,$15,$16,$17}' $tmp > ../$dscovrDsplayTxt
cd ..

#emulate old ace file structure
aceDsplayTxt="ace_magswepam_1m_last4days_every5thvalue.txt"
ace_ap_plotFolder="../ace_ap_plot/"
#test if folder exists, if not create it:
if [ ! -d $ace_ap_plotFolder ]; then mkdir -p $ace_ap_plotFolder; fi
cp $dscovrDsplayTxt $ace_ap_plotFolder$aceDsplayTxt


cd $data
################################
#load latest Kp/ap file:
gfzKpUrl="http://www-app3.gfz-potsdam.de/kp_index/"
kpFile="qlyymm.wdc"
kpFileTemp="qlyymm_temp.wdc"
wget $gfzKpUrl$kpFile -q -N
awk 'BEGIN{FIELDWIDTHS="2 2 2 4 2 2 2 2 2 2 2 2 2 3 3 3 3 3 3 3 3 3 7"} {print "20"$1" "$2" "$3" 00:00 "$6" ap"$15; print "20"$1" "$2" "$3" 03:00 "$7" ap"$16; print "20"$1" "$2" "$3" 06:00 "$8" ap"$17; print "20"$1" "$2" "$3" 09:00 "$9" ap"$18; print "20"$1" "$2" "$3" 12:00 "$10" ap"$19; print "20"$1" "$2" "$3" 15:00 "$11" ap"$20; print "20"$1" "$2" "$3" 18:00 "$12" ap"$21; print "20"$1" "$2" "$3" 21:00 "$13" ap"$22}' $kpFile > $kpFileTemp

#convert ap values to kp27
#sed -i 's/ap  0/0/g' $kpFileTemp
declare -a ap=(0 2 3 4 5 6 7 9 12 15 18 22 27 32 39 48 56 67 80 94 111 132 154 179 207 236 300 400)
declare -a kp27=(0 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27)
for k in {0..7}
do
	sed -i 's/'"ap  ${ap[$k]}"/"${kp27[$k]}"'/g' $kpFileTemp
done
for k in {8..19}
do
	sed -i 's/'"ap ${ap[$k]}"/"${kp27[$k]}"'/g' $kpFileTemp
done
for k in {20..27}
do
	sed -i 's/'"ap${ap[$k]}"/"${kp27[$k]}"'/g' $kpFileTemp
done
cd ..

#run gnuplot: 
#gnuplot dscovr_rtsw_kp_gps.txt

# #emulate old ace file structure
ace_ap_plotFolder="../ace_ap_plot/"
#test if folder exists, if not create it:
if [ ! -d $ace_ap_plotFolder ]; then mkdir -p $ace_ap_plotFolder; fi
# cp "dscovr_rtsw_kp_plot.png" $ace_ap_plotFolder"ace_realtime_ap_plot.png"
mvenzmerURL="http://www.astro.physik.uni-goettingen.de/~mvenzmer/rssfeeds_dscovr/ace_ap_plot"
wget $mvenzmerURL"dscovr_rtsw_kp_plot.png" -q -N -O $ace_ap_plotFolder"ace_realtime_ap_plot.png"


########### CH forecast #######################
#fetch month data file
CHmonthFile="1_month_data.txt"
ugrazCHforecastURL="http://swe.uni-graz.at/solarwind/products/txt/$CHmonthFile"
wget $ugrazCHforecastURL -q -N -P $data

############# CH SW forecast data file for the SW-Display ###############
#convert date and make original data format
CHmonthFileFormatted="CH_forecast_1month_formatted.txt"
awk 'NR!=1 {cmd="date --utc --date=\""$5"-01-01 -1 day +$(echo \""$6"*24*60*60\" | bc) seconds\" +\"%Y %m %d %H%M \""; cmd | getline convdate; close(cmd); print convdate convdate convdate convdate convdate convdate "12345678901234567890123", $7, $5, $6, "         ", $8, "           "}' $data$CHmonthFile > $CHmonthFileFormatted

#emulate old ace file structure
CHfolder="../ace_ap_forecast_plot/CH_forecast_data/"
#test if folder exists, if not create it:
if [ ! -d $CHfolder ]; then mkdir -p $CHfolder; fi
cp $CHmonthFileFormatted $CHfolder"CH_forecast_merged2_with_ap-forecast.txt"


#########  CH Kp forecast via v-Kp table  ###############################
#[...]

########## GFT ap data ##########################
#get *.asc file name from "farm_nrt.cfg", read GFT *.asc file and write conversion into "gft_ap_data.txt":
gft_path="../sri_gft_ap/"
fileName="`awk '/FNDAT/ && !/FORECAST/ {print substr($0,8,24)} END{}' $gft_path"farm_nrt.cfg"`"
#echo $fileName
gftKpFile="gft_kp_data.txt"
awk 'NR!=1 { printf ("%04d %3d %4d %02d %02d %02d00 %3d %3d ap %3d\n", $1,$2,$3,$4,$5,$7,$6,$8,$9)} END{}' "$gft_path$fileName" > $data$gftKpFile
fileNameTime="`awk '/FNDAT/ && !/FORECAST/ {print substr($0,14,14)} END{}' $gft_path"farm_nrt.cfg"`"
#echo $fileNameTime
find $gft_path -name 'ace-mag-rt-*.asc' ! -name "ace-mag-rt-$fileNameTime.asc" -type f | xargs rm -f
find $gft_path -name 'ace-swepam-rt-*.asc' ! -name "ace-swepam-rt-$fileNameTime.asc" -type f | xargs rm -f
find $gft_path -name 'kp-rt-*.asc' ! -name "kp-rt-$fileNameTime.asc" -type f | xargs rm -f
find $gft_path -name 'dst-rt-*.asc' ! -name "dst-rt-$fileNameTime.asc" -type f | xargs rm -f
find $gft_path -name 'ap-fc-*.xml' ! -name "ap-fc-$fileNameTime.xml" -type f | xargs rm -f
find $gft_path -name 'ap-fc-*.asc' ! -name "ap-fc-$fileNameTime.asc" -type f | xargs rm -f

for k in {0..7}
do
	sed -i 's/'"  ${ap[$k]} ap"/"${kp27[$k]}"'/g' $data$gftKpFile
done
for k in {8..19}
do
	sed -i 's/'" ${ap[$k]} ap"/"${kp27[$k]}"'/g' $data$gftKpFile
done
for k in {20..27}
do
	sed -i 's/'"${ap[$k]} ap"/"${kp27[$k]}"'/g' $data$gftKpFile
done


############  Kp nowcast via vBzgsm-Kp table  ###############################
#[...]


#run gnuplot: 
#gnuplot dscovr_rtsw_kp_forecast_gps.txt

#emulate old ace file structure
ace_ap_forecastFolder="../ace_ap_forecast_plot/"
#test if folder exists, if not create it:
if [ ! -d $ace_ap_forecastFolder ]; then mkdir -p $ace_ap_forecastFolder; fi
# cp "dscovr_rtsw_kp_forcast_plot.png" $ace_ap_forecastFolder"ace_realtime_ap_CH_GFT_plot.png"
mvenzmerURL="http://www.astro.physik.uni-goettingen.de/~mvenzmer/rssfeeds_dscovr/ace_ap_forecast_plot/"
wget $mvenzmerURL"dscovr_rtsw_kp_forecast_plot.png" -q -N -O $ace_ap_forecastFolder"ace_realtime_ap_ch_gft_plot.png"


echo "`date --utc -d 'now' '+%Y-%m-%d %H:%M:%S %Z on %A '`$thisFile" >> $thisFilePath"/skript_log.txt"







